(contributing)=

# Contributing

The contributing guide goes over the details necessary to contribute to SymPy.

If you are new to contributing to SymPy, start with the
[](introduction-to-contributing).

**Content**

```{toctree}
:titlesonly: true

introduction-to-contributing.md
new-contributors-guide/index.md
dependencies.md
debug.rst
docstring.rst
documentation-style-guide.rst
deprecations.md
```
